%%
%% %CopyrightBegin%
%%
%% SPDX-License-Identifier: Apache-2.0
%%
%% Copyright Ericsson AB 2026. All Rights Reserved.
%%
%% Licensed under the Apache License, Version 2.0 (the "License");
%% you may not use this file except in compliance with the License.
%% You may obtain a copy of the License at
%%
%%     http://www.apache.org/licenses/LICENSE-2.0
%%
%% Unless required by applicable law or agreed to in writing, software
%% distributed under the License is distributed on an "AS IS" BASIS,
%% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
%% See the License for the specific language governing permissions and
%% limitations under the License.
%%
%% %CopyrightEnd%
%%

-module(ct_doctest_function_parse_error_mod).
-moduledoc false.
-export([f/0, g/0, h/0, i/0, j/0]).

-doc """
```
1> ).
ok
```
""".
f() ->
    ok.

-doc """
```
%% Missing fullstop
1> 1 + 2
3
```
""".
g() ->
    ok.


-doc """
```
1> 1 + 2, .
4
```
""".
h() ->
    ok.

-doc """
```
1> 1 + 2, 
4
```
""".
i() ->
    ok.

-doc """
```
1> 1 + 2.
3
2> 1 + 2,
  1 + 3
4
```
""".
j() ->
    ok.

